#! /bin/sh
#----------------------------------------------------------------------
#program to check everything is ready to start clement
#----------------------------------------------------------------------
#Hard coded variables
APPNAME=clement
PLOCK=/var/lock/subsys
#----------------------------------------------------------------------
#all applications variables
[ -f /etc/$APPNAME/$APPNAME.conf ] && . /etc/$APPNAME/$APPNAME.conf
#overiding some variable by local setting
[ -f /etc/sysconfig/$APPNAME ] && . /etc/sysconfig/$APPNAME
#----------------------------------------------------------------------
#restarting a daemon
#$1 daemon application name
sh_restart()

{
service $1 restart
}
#----------------------------------------------------------------------
#reporting a big trouble
sh_failure()

{
echo "Failure: $1"
}
#----------------------------------------------------------------------
#reporting a small problem
sh_warning()

{
echo "Warning: $1"
}
#----------------------------------------------------------------------
#reporting a success
sh_success()

{
echo "Success: $1"
}
#----------------------------------------------------------------------
#adding dovecot configuration
#----------------------------------------------------------------------
do_doveconf()

{
export	BEFCLEM=/etc/dovecot.conf.before.$APPNAME
export	DOVCONF=/etc/dovecot.conf
export  NEWCONF=/etc/$APPNAME/dovecot-1.2.conf
ln -nsf	/etc/$APPNAME/dovecot-1.2-auth-sql.conf	\
	/etc/$APPNAME/dovecot-auth-sql.conf
ln -nsf	/etc/$APPNAME/dovecot-1.2-auth-ldap.conf	\
	/etc/$APPNAME/dovecot-auth-ldap.conf

if [ ! -f $DOVCONF ] ; then
  export BEFCLEM=/etc/dovecot/dovecot.conf.before.$APPNAME
  export DOVCONF=/etc/dovecot/dovecot.conf
  export NEWCONF=/etc/$APPNAME/dovecot-2.0.conf
  ln -nsf	/etc/$APPNAME/dovecot-2.0-auth-sql.conf	\
		/etc/$APPNAME/dovecot-auth-sql.conf
  ln -nsf	/etc/$APPNAME/dovecot-2.0-auth-ldap.conf	\
		/etc/$APPNAME/dovecot-auth-ldap.conf
  fi

if [ -f $DOVCONF ] ; then
  if [ ! -f $BEFCLEM ] ; then
    mv $DOVCONF $BEFCLEM
    ln -s $NEWCONF $DOVCONF
    ln -s $DOVCONF /etc/$APPNAME/dovecot.conf
    cat  /etc/$APPNAME/dovecot-auth.conf >> $DOVCONF
    fi
  fi
}
#----------------------------------------------------------------------
#building application data-base
#----------------------------------------------------------------------
do_mkdb()

{
case "$DB_TYPE" in
  "MYSQLI"	|		\
  "MYSQL"	)
    #now we have control over mysql daemon
    (
    echo "CREATE USER 'apache'@'localhost';"
    echo "CREATE USER 'dovecot'@'localhost';"
    echo "CREATE USER '$APPNAME'@'localhost';"
    ) | mysql -u root mysql >> /etc/$APPNAME/dbinst.log
    /usr/lib/$APPNAME/support/crdb.sh "/"
    ;;
  "POSTGRESQL"	)
    /usr/lib/$APPNAME/support/crdb.sh "/"
    ;;
  "NOT_DEFINED"	)
    echo "You must install $APPNAME with a DB flavor (ex: $APPNAME-pgsql, $APPNAME-mysql)"
    echo "Exiting now"
    exit -2;
    ;;
  "*"		)
    echo "Unexpectd DB_TYPE variable within /etc/sysconfig/$APPNAME, please check"
    echo "Exiting now"
    exit -3;
    ;;
  esac
/usr/lib/$APPNAME/support/mkdb.sh "/"
chown $APPNAME /etc/$APPNAME/dbinst.sql
chown $APPNAME /etc/$APPNAME/dbinst.log
(
export hostipv4=`dig \`uname -n\` A +noall +short | head -1`;
export hostipv6=`dig \`uname -n\` AAAA +noall +short | head -1`;
#to make sure we have at least an hostipv4 reference
if [ -z "$hostipv4" -a -z "$hostipv6" ] ; then
  export hostipv4=`grep \`uname -n\` /etc/hosts | cut  -f1`
  fi

/bin/su - -m $APPNAME << !EOT
export SMTPPORT0=25;
export SMTPPORT1=587;
export SMTPPORT3=465;
export SMTPIPV4=$hostipv4;
export SMTPIPV6=$hostipv6;
export RPASS=`grep root /etc/shadow | cut -d':' -f2 | sed -e "s:\\\\$:\\\\\\\\$:g"`;
export DOMAINNAME=`dnsdomainname`;
export HOSTNAME=`hostname`;
export SPAMID=$APPNAME;
/usr/lib/$APPNAME/support/clmmkdb.sh "" /etc/$APPNAME/base.sql
!EOT
)
}
#----------------------------------------------------------------------
#procedure to check if the config is properly done
#you MUST AT LEAST, specify the Data Base type to be used by clement.
#----------------------------------------------------------------------
chk_config()

{
if      [ -z "$DB_TYPE" -o "$DB_TYPE" = "TO_BE_DEFINED" ] ; then
  echo -n "Checking file /etc/$APPNAME/$APPNAME.conf"
  sh_failure $" ->> not configured"
  echo -e "\tPlease set DB_TYPE within /etc/$APPNAME/$APPNAME.conf"
  echo -e "\tAborting start, Exiting at once"
  exit -1;
  fi
}
#----------------------------------------------------------------------
#procedure to check if we are able to find at least one IPV4 number
#linked to system name
#----------------------------------------------------------------------
chk_uname()

{
hostipv4=`dig \`uname -n\` A +noall +short`;
hostipv6=`dig \`uname -n\` AAAA +noall +short`;
#to make sure we have at least an hostipv4 reference
if [ -z "$hostipv4" -a -z "$hostipv6" ] ; then
  hostipv4=`grep \`uname -n\` /etc/hosts | cut  -f1`
  fi
#double checking if we have an IPV4
if [ -z "$hostipv4" -a -z "$hostipv6" ] ; then
  echo "Unable to find a IP number link to this server "`uname -n`
  echo "Fix your DNS or your /etc/hosts file, to have at least one IP number"
  echo "returned by next line command line"
  echo "> grep \`uname -n\` /etc/hosts | cut  -f1"
  echo "Exiting now"
  exit -1;
  fi
}
#----------------------------------------------------------------------
#procedure to check if data-base server is available
#----------------------------------------------------------------------
chk_dbsrv()

{
case "$DB_TYPE" in
  "MYSQLI"	|		\
  "MYSQL"       )
    /etc/init.d/mysqld status
    if [ $? != 0 ] ; then
      echo "You must have mysql daemon (mysqld) up and running"
      echo "before to start clement"
      echo "See: \"service mysqld start\""
      echo "Exiting now"
      exit -1;
      fi
    ;;
  "POSTGRESQL"  )
    /etc/init.d/postgresql status
    if [ $? != 0 ] ; then
      echo "You must have postgresql daemon (postmaster) up and running"
      echo "before to start clement"
      echo "see: \"service postgresql start\""
      echo "Exiting now"
      exit -1;
      fi
    ;;
  "NOT_DEFINED" )
    echo "You must have a data-base daemon with a DB flavor (ex: postgresql, mysqld) defined"
    echo "See /etc/sysconfig/$APPNAME file"
    echo "Exiting now"
    exit -2;
    ;;
  "*"           )
    echo "Unexpectd DB_TYPE variable within /etc/sysconfig/$APPNAME, please check"
    echo "Exiting now"
    exit -3;
    ;;
  esac
}
#----------------------------------------------------------------------
#creating clement local certificat
#----------------------------------------------------------------------
do_mkcert()

{
if [ ! -f /etc/pki/$APPNAME/$APPNAME-cert.pem ] ; then
  echo -n $"Preparing $APPNAME certificat: "
  /usr/lib/$APPNAME/support/dummy-cert 			\
	 /etc/pki/$APPNAME/$APPNAME
  chown $APPNAME:mail					\
	 /etc/pki/$APPNAME/$APPNAME-cert.pem		\
	 /etc/pki/$APPNAME/$APPNAME-key.pem
  sh_success $"certs generation"
  fi
}
#----------------------------------------------------------------------
#setting local clement configuration
#----------------------------------------------------------------------
do_mkconf()

{
if [ ! -f /etc/$APPNAME/config.done ] ; then
  /usr/lib/$APPNAME/support/addconfig.sh
  sh_success $"conf addition"
  do_mkdb ;
  do_doveconf ;
  sh_restart httpd
  sh_restart dovecot
  date > /etc/$APPNAME/config.done
fi
}
#----------------------------------------------------------------------
#procedure to check if spamassassin is up and running
#----------------------------------------------------------------------
chk_spamd()

{
/etc/init.d/spamassassin status
if [ $? != 0 ] ; then
  sh_warning $1 $"Spamassassin daemon is NOT found up and running!"
 echo $"use 'chkconfig spamassassin on' to start spammassin each time"
 fi
}
#----------------------------------------------------------------------
#procedure to check if freshclam and clamd are up and running
#----------------------------------------------------------------------
chk_clam()

{
/etc/init.d/clamd status
if [ $? != 0 ] ; then
  sh_warning $"clamd daemon is NOT found up and running!"
  echo "use 'chkconfig clamd on' to start spammassin each time"
  fi
}
#----------------------------------------------------------------------
#main program

export COLUMNS=80
chk_config;
chk_uname;
chk_dbsrv;
do_mkcert;
do_mkconf;
chk_spamd;
chk_clam;
/usr/lib/$APPNAME/support/genphp.sh
exit 0;
